@@ -6,7 +6,9 @@
 
 #include "connection.h"
 
-#include <QtDBus>
+#include <QDBusConnection>
+#include <QDBusMessage>
+#include <QDBusMetaType>
 
 Connection::Connection(QObject *parent, const NMVariantMapMap &settings)
     : QObject(parent)
@@ -76,3 +78,5 @@ void Connection::setConnectionPath(const QString &path)
 {
     m_connectionPath = path;
 }
+
+#include "moc_connection.cpp"
