@@ -9,6 +9,10 @@
 
 #include <QDebug>
 
+#if !NM_CHECK_VERSION(1, 10, 0)
+#define NM_SETTING_WIRELESS_SECURITY_PMF "pmf"
+#endif
+
 NetworkManager::WirelessSecuritySettingPrivate::WirelessSecuritySettingPrivate()
     : name(NM_SETTING_WIRELESS_SECURITY_SETTING_NAME)
     , keyMgmt(NetworkManager::WirelessSecuritySetting::Unknown)
@@ -18,12 +22,15 @@ NetworkManager::WirelessSecuritySettingPrivate::WirelessSecuritySettingPrivate()
     , wepKeyType(NetworkManager::WirelessSecuritySetting::NotSpecified)
     , pskFlags(NetworkManager::Setting::None)
     , leapPasswordFlags(NetworkManager::Setting::None)
-{ }
+    , pmf(NetworkManager::WirelessSecuritySetting::DefaultPmf)
+{
+}
 
 NetworkManager::WirelessSecuritySetting::WirelessSecuritySetting()
     : Setting(Setting::WirelessSecurity)
     , d_ptr(new WirelessSecuritySettingPrivate())
-{ }
+{
+}
 
 NetworkManager::WirelessSecuritySetting::WirelessSecuritySetting(const Ptr &other)
     : Setting(other)
@@ -45,6 +52,7 @@ NetworkManager::WirelessSecuritySetting::WirelessSecuritySetting(const Ptr &othe
     setPskFlags(other->pskFlags());
     setLeapPassword(other->leapPassword());
     setLeapPasswordFlags(other->leapPasswordFlags());
+    setPmf(other->pmf());
 }
 
 NetworkManager::WirelessSecuritySetting::~WirelessSecuritySetting()
@@ -101,42 +109,42 @@ NetworkManager::WirelessSecuritySetting::AuthAlg NetworkManager::WirelessSecurit
     return d->authAlg;
 }
 
-void NetworkManager::WirelessSecuritySetting::setProto(const QList< NetworkManager::WirelessSecuritySetting::WpaProtocolVersion > &list)
+void NetworkManager::WirelessSecuritySetting::setProto(const QList<NetworkManager::WirelessSecuritySetting::WpaProtocolVersion> &list)
 {
     Q_D(WirelessSecuritySetting);
 
     d->proto = list;
 }
 
-QList< NetworkManager::WirelessSecuritySetting::WpaProtocolVersion > NetworkManager::WirelessSecuritySetting::proto() const
+QList<NetworkManager::WirelessSecuritySetting::WpaProtocolVersion> NetworkManager::WirelessSecuritySetting::proto() const
 {
     Q_D(const WirelessSecuritySetting);
 
     return d->proto;
 }
 
-void NetworkManager::WirelessSecuritySetting::setPairwise(const QList< NetworkManager::WirelessSecuritySetting::WpaEncryptionCapabilities > &list)
+void NetworkManager::WirelessSecuritySetting::setPairwise(const QList<NetworkManager::WirelessSecuritySetting::WpaEncryptionCapabilities> &list)
 {
     Q_D(WirelessSecuritySetting);
 
     d->pairwise = list;
 }
 
-QList< NetworkManager::WirelessSecuritySetting::WpaEncryptionCapabilities > NetworkManager::WirelessSecuritySetting::pairwise() const
+QList<NetworkManager::WirelessSecuritySetting::WpaEncryptionCapabilities> NetworkManager::WirelessSecuritySetting::pairwise() const
 {
     Q_D(const WirelessSecuritySetting);
 
     return d->pairwise;
 }
 
-void NetworkManager::WirelessSecuritySetting::setGroup(const QList< NetworkManager::WirelessSecuritySetting::WpaEncryptionCapabilities > &list)
+void NetworkManager::WirelessSecuritySetting::setGroup(const QList<NetworkManager::WirelessSecuritySetting::WpaEncryptionCapabilities> &list)
 {
     Q_D(WirelessSecuritySetting);
 
     d->group = list;
 }
 
-QList< NetworkManager::WirelessSecuritySetting::WpaEncryptionCapabilities > NetworkManager::WirelessSecuritySetting::group() const
+QList<NetworkManager::WirelessSecuritySetting::WpaEncryptionCapabilities> NetworkManager::WirelessSecuritySetting::group() const
 {
     Q_D(const WirelessSecuritySetting);
 
@@ -297,6 +305,20 @@ NetworkManager::Setting::SecretFlags NetworkManager::WirelessSecuritySetting::le
     return d->leapPasswordFlags;
 }
 
+void NetworkManager::WirelessSecuritySetting::setPmf(NetworkManager::WirelessSecuritySetting::Pmf pmf)
+{
+    Q_D(WirelessSecuritySetting);
+
+    d->pmf = pmf;
+}
+
+NetworkManager::WirelessSecuritySetting::Pmf NetworkManager::WirelessSecuritySetting::pmf() const
+{
+    Q_D(const WirelessSecuritySetting);
+
+    return d->pmf;
+}
+
 void NetworkManager::WirelessSecuritySetting::secretsFromMap(const QVariantMap &secrets)
 {
     if (secrets.contains(QLatin1String(NM_SETTING_WIRELESS_SECURITY_WEP_KEY0))) {
@@ -390,8 +412,7 @@ QStringList NetworkManager::WirelessSecuritySetting::needSecrets(bool requestNew
         }
     }
 
-    if (keyMgmt() == WpaNone ||
-            keyMgmt() == WpaPsk || keyMgmt() == SAE) {
+    if (keyMgmt() == WpaNone || keyMgmt() == WpaPsk || keyMgmt() == SAE) {
         if (!pskFlags().testFlag(Setting::NotRequired)) {
             if (psk().isEmpty() || requestNew) {
                 secrets << QLatin1String(NM_SETTING_WIRELESS_SECURITY_PSK);
@@ -400,8 +421,7 @@ QStringList NetworkManager::WirelessSecuritySetting::needSecrets(bool requestNew
         }
     }
 
-    if (authAlg() == Leap &&
-            keyMgmt() == Ieee8021x) {
+    if (authAlg() == Leap && keyMgmt() == Ieee8021x) {
         if (!leapPasswordFlags().testFlag(Setting::NotRequired)) {
             if (leapPassword().isEmpty() || requestNew) {
                 secrets << QLatin1String(NM_SETTING_WIRELESS_SECURITY_LEAP_PASSWORD);
@@ -429,6 +449,10 @@ void NetworkManager::WirelessSecuritySetting::fromMap(const QVariantMap &map)
             setKeyMgmt(WpaEap);
         } else if (key == "sae") {
             setKeyMgmt(SAE);
+        } else if (key == "wpa-eap-suite-b-192") {
+            setKeyMgmt(WpaEapSuiteB192);
+        } else if (key == "owe") {
+            setKeyMgmt(OWE);
         }
     }
 
@@ -543,6 +567,10 @@ void NetworkManager::WirelessSecuritySetting::fromMap(const QVariantMap &map)
     if (map.contains(QLatin1String(NM_SETTING_WIRELESS_SECURITY_LEAP_PASSWORD_FLAGS))) {
         setLeapPasswordFlags((SecretFlags)map.value(QLatin1String(NM_SETTING_WIRELESS_SECURITY_LEAP_PASSWORD_FLAGS)).toInt());
     }
+
+    if (map.contains(QLatin1String(NM_SETTING_WIRELESS_SECURITY_PMF))) {
+        setPmf((Pmf)map.value(QLatin1String(NM_SETTING_WIRELESS_SECURITY_PMF)).toInt());
+    }
 }
 
 QVariantMap NetworkManager::WirelessSecuritySetting::toMap() const
@@ -561,6 +589,10 @@ QVariantMap NetworkManager::WirelessSecuritySetting::toMap() const
         setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_KEY_MGMT), "wpa-eap");
     } else if (keyMgmt() == SAE) {
         setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_KEY_MGMT), "sae");
+    } else if (keyMgmt() == WpaEapSuiteB192) {
+        setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_KEY_MGMT), "wpa-eap-suite-b-192");
+    } else if (keyMgmt() == OWE) {
+        setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_KEY_MGMT), "owe");
     }
 
     if (wepTxKeyindex()) {
@@ -674,10 +706,14 @@ QVariantMap NetworkManager::WirelessSecuritySetting::toMap() const
         setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_LEAP_PASSWORD_FLAGS), (int)leapPasswordFlags());
     }
 
+    if (pmf()) {
+        setting.insert(QLatin1String(NM_SETTING_WIRELESS_SECURITY_PMF), (int)pmf());
+    }
+
     return setting;
 }
 
-QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::WirelessSecuritySetting &setting)
+QDebug NetworkManager::operator<<(QDebug dbg, const NetworkManager::WirelessSecuritySetting &setting)
 {
     dbg.nospace() << "type: " << setting.typeAsString(setting.type()) << '\n';
     dbg.nospace() << "initialized: " << !setting.isNull() << '\n';
@@ -699,6 +735,7 @@ QDebug NetworkManager::operator <<(QDebug dbg, const NetworkManager::WirelessSec
     dbg.nospace() << NM_SETTING_WIRELESS_SECURITY_PSK_FLAGS << ": " << setting.pskFlags() << '\n';
     dbg.nospace() << NM_SETTING_WIRELESS_SECURITY_LEAP_PASSWORD << ": " << setting.leapPassword() << '\n';
     dbg.nospace() << NM_SETTING_WIRELESS_SECURITY_LEAP_PASSWORD_FLAGS << ": " << setting.leapPasswordFlags() << '\n';
+    dbg.nospace() << NM_SETTING_WIRELESS_SECURITY_PMF << ": " << setting.pmf() << '\n';
 
     return dbg.maybeSpace();
 }
